# Roboherd

Roboherd is a framework for building Fediverse bots
using the [Cattle Drive Protocol](https://bovine.codeberg.page/cattle_grid/cattle_drive/).

For more information, see the [documentation](https://bovine.codeberg.page/roboherd/) or the [repository](https://codeberg.org/bovine/roboherd/).
